@@ -2,11 +2,10 @@ import http.client
 import logging
 import os
 from base64 import b64decode
-from typing import Any, List, Type
+from typing import List, Type
 
 import click
 
-from memfault_cli.authenticator import Authenticator
 from memfault_cli.chunk import MemfaultChunk
 from memfault_cli.context import MemfaultCliClickContext
 from memfault_cli.deploy import Deployer
@@ -43,6 +42,7 @@ click_option_revision = click.option(
     "--password", prompt=False, help="Account password or user API key to authenticate with"
 )
 @click.option("--project-key", help="Memfault Project Key")
+@click.option("--org-token", help="Organization Auth Token")
 @click.option("--org", help="Organization slug")
 @click.option("--project", help="Project slug")
 @click.option("--url", hidden=True)
@@ -71,7 +71,7 @@ def cli(ctx: MemfaultCliClickContext, **kwargs):
 
 
 def _do_upload_or_raise(ctx: MemfaultCliClickContext, path: str, uploader_cls: Type[Uploader]):
-    authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
+    authenticator = ctx.authenticator
     ctx.check_required_cli_args(authenticator=authenticator)
 
     uploader = uploader_cls(ctx=ctx, file_path=path, authenticator=authenticator)
@@ -268,15 +268,14 @@ def deploy_release(
     """
     ctx.obj.update(**kwargs)
 
-    authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
-    ctx.check_required_cli_args(authenticator=authenticator)
+    ctx.check_required_cli_args(authenticator=ctx.authenticator)
 
-    deployer = Deployer(ctx=ctx, authenticator=authenticator)
+    deployer = Deployer(ctx=ctx, authenticator=ctx.authenticator)
     deployer.deploy(release_version=release_version, cohort=cohort, rollout_percent=rollout_percent)
 
 
 def _do_post_chunks_or_raise(ctx: MemfaultCliClickContext, chunks: List[bytes]):
-    authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
+    authenticator = ctx.authenticator
     ctx.check_required_cli_args(authenticator=authenticator)
     if not authenticator.project_key_auth():
         raise click.exceptions.UsageError("A '--project-key' is required")
