@@ -3,6 +3,7 @@ from typing import Optional
 import click
 
 from memfault_cli.authenticator import Authenticator
+from memfault_cli.functools_ext import cached_property
 
 
 class PackageInfo:  # noqa: B903 - no data classes in Python 3.6
@@ -46,10 +47,18 @@ class MemfaultCliClickContext(object):
         for arg in required_args:
             self._find_obj_or_raise(arg)
 
+    @cached_property
+    def authenticator(self) -> Authenticator:
+        return Authenticator.create_authenticator_given_context_or_raise(self)
+
     @property
     def org(self):
         return self._find_obj_or_raise("org")
 
+    @property
+    def org_token(self) -> str:
+        return self._find_obj_or_raise("org_token")
+
     @property
     def project(self):
         return self._find_obj_or_raise("project")
